@@ -36,8 +36,9 @@ class Odoo():
     res = self.models.execute_kw(self.db, self.uid, self.password, object, 'write', [[id], fields])
     return res
   
-  def readModel(self, object, ids):
-    [res] = self.models.execute_kw(self.db, self.uid, self.password, object, 'read', [ids])
-    print(json.dumps(res))
-    return res
-    
\ No newline at end of file
+  def readModel(self, object, ids, fields=[]):
+    if len(fields) > 0:
+      [res] = self.models.execute_kw(self.db, self.uid, self.password, object, 'read', [ids], {'fields': fields})
+    else:
+      [res] = self.models.execute_kw(self.db, self.uid, self.password, object, 'read', [ids])
+    return res
\ No newline at end of file
